==> 3.5.12-core.tar: kdevelop/parts/filelist/filelist_widget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Jens Dagerbo                                    *
 *   jens.dagerbo@swipnet.se                                               *
 *   Copyright (C) 2005 by Jens Herden                                     *
 *   jens@kdewebdev.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __FILELIST_WIDGET_H__
#define __FILELIST_WIDGET_H__


#include <klistview.h>
#include <kurl.h>
#include <kdevpartcontroller.h> // for DocumentState

#include <tqstring.h>
#include <tqtooltip.h>
#include <tqtimer.h>

#include "projectviewpart.h"
		 
class KDevProject;
class FileListItem;

namespace KParts { class Part; }

class FileListWidget : public KListView, public QToolTip
{
  Q_OBJECT
    
public:
		  
	FileListWidget(ProjectviewPart *part, TQWidget *parent=0);
  	~FileListWidget();
	
protected:
  	void maybeTip( TQPoint const & );

private slots:
//	void partAdded(KParts::Part*);
//	void partRemoved();
	void activePartChanged(KParts::Part*);
	void itemClicked( TQListViewItem * );
	void popupMenu( TQListViewItem * , const TQPoint & , int );
	void closeSelectedFiles();
	void saveSelectedFiles();
	void reloadSelectedFiles();
	void documentChangedState( const KURL &, DocumentState );
	void refreshFileList();
	void startRefreshTimer();
	TQStringList storeSelections();
	void restoreSelections( const TQStringList & list );

private:
	KURL::List getSelectedURLs();
	FileListItem * itemForURL( KURL const & url );

	TQTimer m_refreshTimer;
	ProjectviewPart * _part;

};


#endif

// kate: space-indent off; indent-width 4; tab-width 4; show-tabs off;

==> 3.5.13-core.tar: kdevelop/parts/filelist/filelist_widget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Jens Dagerbo                                    *
 *   jens.dagerbo@swipnet.se                                               *
 *   Copyright (C) 2005 by Jens Herden                                     *
 *   jens@kdewebdev.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __FILELIST_WIDGET_H__
#define __FILELIST_WIDGET_H__


#include <klistview.h>
#include <kurl.h>
#include <kdevpartcontroller.h> // for DocumentState

#include <tqstring.h>
#include <tqtooltip.h>
#include <tqtimer.h>

#include "projectviewpart.h"
		 
class KDevProject;
class FileListItem;

namespace KParts { class Part; }

class FileListWidget : public KListView, public TQToolTip
{
  Q_OBJECT
  TQ_OBJECT
    
public:
		  
	FileListWidget(ProjectviewPart *part, TQWidget *parent=0);
  	~FileListWidget();
	
protected:
  	void maybeTip( TQPoint const & );

private slots:
//	void partAdded(KParts::Part*);
//	void partRemoved();
	void activePartChanged(KParts::Part*);
	void itemClicked( TQListViewItem * );
	void popupMenu( TQListViewItem * , const TQPoint & , int );
	void closeSelectedFiles();
	void saveSelectedFiles();
	void reloadSelectedFiles();
	void documentChangedState( const KURL &, DocumentState );
	void refreshFileList();
	void startRefreshTimer();
	TQStringList storeSelections();
	void restoreSelections( const TQStringList & list );

private:
	KURL::List getSelectedURLs();
	FileListItem * itemForURL( KURL const & url );

	TQTimer m_refreshTimer;
	ProjectviewPart * _part;

};


#endif

// kate: space-indent off; indent-width 4; tab-width 4; show-tabs off;
